==> haskell-asn1-parse-0.9.4-114-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-parse
version: 0.9.4
id: asn1-parse-0.9.4-8cyIiT2t6vUHTYMFQpCtRh
key: asn1-parse-0.9.4-8cyIiT2t6vUHTYMFQpCtRh
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-asn1
synopsis: Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.
category: Data
abi: a6f264a51cc413dc61802cf435e7bd85
exposed: True
exposed-modules:
    Data.ASN1.Parse
import-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-parse-0.9.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-parse-0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/asn1-parse-0.9.4
hs-libraries: HSasn1-parse-0.9.4-8cyIiT2t6vUHTYMFQpCtRh
depends:
    asn1-encoding-0.9.5-EB58EapF6z449w8t1NTabZ
    asn1-types-0.3.3-7z9CB8aq8VCJkGLUUe9y5o base-4.12.0.0
    bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html: /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-parse-0.9.4-115-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-parse
version: 0.9.4
id: asn1-parse-0.9.4-8Duvwvi8W6IKNdfs9Uokt7
key: asn1-parse-0.9.4-8Duvwvi8W6IKNdfs9Uokt7
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-asn1
synopsis: Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.
category: Data
abi: 4d29fb386e2cc054eeb951ceb84e7bbb
exposed: True
exposed-modules:
    Data.ASN1.Parse
import-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-parse-0.9.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-parse-0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/asn1-parse-0.9.4
hs-libraries: HSasn1-parse-0.9.4-8Duvwvi8W6IKNdfs9Uokt7
depends:
    asn1-encoding-0.9.6-IOecD5h1VTO2e6wAGqxYer
    asn1-types-0.3.3-7z9CB8aq8VCJkGLUUe9y5o base-4.12.0.0
    bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html: /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
